Learn R Programming

rgoogleclassroom (version 1.0.0)

bad_quiz_path: Path to bad example quiz

Description

Path to bad example quiz

Usage

bad_quiz_path()

Arguments

Value

The file path to an example bad quiz included in the package that will fail the quiz checks.

Examples

Run this code

quiz_path <- bad_quiz_path()

Run the code above in your browser using DataLab